%% Bode Plots for Second-Order Integrators and Differentiators
% This file generates Bode plots for systems that integrate twice or 
% differentiate twice the input signal.

%% Second-Order Integrator (Double Integrator)
% The dynamics of a double integrator are: d^2(y)/dt^2 = u 
% In other words, the output is simply the second integral of the input.
% The corresponding transfer function is G(s) = 1/s^2.

% Create transfer function and state-space form for an integrator
G = tf(1,[1 0 0]);

% Create Bode Plot
[Gmag,Gph_deg,w] = bode(G);
Gmag = Gmag(:);
Gph_deg = Gph_deg(:);
Gmag_dB = 20*log10(Gmag);

figure(1); clf;
subplot(2,1,1)
semilogx(w,Gmag_dB,'b')
ylabel('Magnitude (dB)');
title('Bode Diagram');
grid on;
set(gca,'LineWidth',1,'Ytick',[-40 -12 0 12 40]);
set(gca,'Xtick',[0.1 0.5 1 2 10]);

subplot(2,1,2)
semilogx(w,Gph_deg,'b')
ylim([-225 0]);
ylabel('Phase (deg)');
xlabel('Frequency (rad/sec)');
set(gca,'LineWidth',1,'Ytick',[-225 -180 -90 0]);
set(gca,'Xtick',[0.1 0.5 1 2 10]);
grid on;

% Save Plots
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(1)
    garyfyFigure
    myprint(1,'Int2Bode')    
end

%% Second-Order Differentiator (Double Differentiator)
% The dynamics of an differentiator are: y = d^2(u)/dt^2
% In other words, the output is simply the second derivative of the input.
% The corresponding transfer function is G(s) = s^2/1 = s^2.

% Create transfer function for a differentiator
G = tf([1 0 0],1);

% Create Bode Plot
[Gmag,Gph_deg,w] = bode(G);
Gmag = Gmag(:);
Gph_deg = Gph_deg(:);
Gmag_dB = 20*log10(Gmag);

figure(2); clf;
subplot(2,1,1)
semilogx(w,Gmag_dB,'b')
ylabel('Magnitude (dB)');
title('Bode Diagram');
grid on;
set(gca,'LineWidth',1,'Ytick',[-40 -12 0 12 40]);
set(gca,'Xtick',[0.1 0.5 1 2 10]);

subplot(2,1,2)
semilogx(w,Gph_deg,'b')
ylim([0 225]);
ylabel('Phase (deg)');
xlabel('Frequency (rad/sec)');
set(gca,'LineWidth',1,'Ytick',[0 90 180 225]);
set(gca,'Xtick',[0.1 0.5 1 2 10]);
grid on;

% Save Plots
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(2)
    garyfyFigure
    myprint(2,'Dif2Bode')    
end


