%% Low and High Frequency Signals


%% Reset random number generator
% This allows the results\ for the random signal to be repeatable.
stream = RandStream.getGlobalStream;
reset(stream);


%% Specify System
G = tf(10,[1 10]);

% Draw Bode plot
[Gmag,Gph_deg,w] = bode(G);
Gmag = Gmag(:);
Gph_deg = Gph_deg(:);
Gmag_dB = 20*log10(Gmag);

figure(1)
clf;
subplot(2,1,1)
semilogx(w,Gmag_dB,'b')
ylabel('Magnitude (dB)');
title('Bode Diagram');
grid on;
set(gca,'YTick',[-40 -20 -6 0],'LineWidth',1);

subplot(2,1,2)
semilogx(w,Gph_deg,'b')
ylim([-90 0]);
ylabel('Phase (deg)');
xlabel('Frequency (rad/sec)');
set(gca,'YTick',[-90 -45 0],'LineWidth',1);
grid on;

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(1)
    garyfyFigure    
    myprint(1,'LFandHFBode')
end


%% Specify signals
N = 1000;
T = 10;
t = linspace(0,T,N);
t = t(:);

% Slow ramp up and down
idx1 = t<2;
idx2 = t>=2 & t<=8;
idx3 = t>8;
u1 = zeros(N,1);
u1(idx1) = 1-cos(pi*t(idx1)/2);
u1(idx2) = 2;
u1(idx3) = 1+cos( pi*(t(idx3)-8)/2 );

% Random noise
u2 = randn(N,1);

%% Linear responses
[y1,t]=lsim(G,u1,t);
[y2,t]=lsim(G,u2,t);


% Plot results
figure(2); 
clf
subplot(2,1,1)
plot(t,u1,'b',t,y1,'r-.')
legend('Input, u','Output, y','Location','Best');
grid on;
xlabel('Time, sec');
ylim([0 2.5]);
set(gca, 'LooseInset', get(gca, 'TightInset'));

subplot(2,1,2)
plot(t,u2,'b',t,y2,'r-.')
legend('Input, u','Output, y','Location','Southeast');
grid on;
xlabel('Time, sec');
ylim([-4 4]);
set(gca, 'LooseInset', get(gca, 'TightInset'));

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(2)
    garyfyFigure    
    myprint(2,'LFandHFResp')
end

%% Frequency Components: Low Frequency Signal

% The Discrete Fourier Transform is applied on the sampled data.
[A,~,w] = cosDFT(u1,t);
Ncos = numel(A);
ww=[w w w]'; 
AA = [zeros(Ncos,1) A zeros(Ncos,1)]';

[Ay,~,wy] = cosDFT(y1,t);
Ncos = numel(Ay);
wwy=[wy wy wy]'; 
AAy = [zeros(Ncos,1) Ay zeros(Ncos,1)]';

figure(3);
clf
subplot(2,1,1)
plot(ww,AA,'b',w,A,'bo');
ylabel('Input Amp., A_k');
title('Frequency Content');
grid on;
xlim([0 15]);
set(gca, 'LooseInset', get(gca, 'TightInset'));

subplot(2,1,2)
plot(wwy,AAy,'r',wy,Ay,'ro');
ylabel('Output Amp., A_k');
xlabel('Frequency \omega_k, rad/sec');
grid on;
xlim([0 15]);
set(gca, 'LooseInset', get(gca, 'TightInset'));


% Save Plots
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(3)
    garyfyFigure
    myprint(3,'LFandHFAmp1')
end

%% Frequency Components: High Frequency Signal

% The Discrete Fourier Transform is applied on the sampled data.
[A,~,w] = cosDFT(u2,t);
Ncos = numel(A);
ww=[w w w]'; 
AA = [zeros(Ncos,1) A zeros(Ncos,1)]';

[Ay,~,wy] = cosDFT(y2,t);
Ncos = numel(Ay);
wwy=[wy wy wy]'; 
AAy = [zeros(Ncos,1) Ay zeros(Ncos,1)]';

figure(4);
clf
subplot(2,1,1)
plot(ww,AA,'b',w,A,'bo');
ylabel('Input Amp., A_k');
title('Frequency Content');
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));
xlim([0 wy(end)]);

subplot(2,1,2)
plot(wwy,AAy,'r',wy,Ay,'ro');
ylabel('Output Amp., A_k');
xlabel('Frequency \omega_k, rad/sec');
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));
xlim([0 wy(end)]);

% Save Plots
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(4)
    garyfyFigure
    myprint(4,'LFandHFAmp2')
end
